# AwsIBox
AwsIBox - **AWS** **I**nfrastructure in a **Box**

Work in progres...

Guidelines:
- Infrastructure as code.
- Same cloudformation template for all environments and regions (Ex. development and production).
- Scalable as needed.

## Installation ##
`pip install awsibox`

## License ##

This software is distributed under the terms of the MIT [license](LICENSE).
